JasonWoof Got questions, comments, patches, etc.? Contact Jason Woofenden
Fix db_get_value after mysql->mysqli upgrade
[wfpl.git] / http.php
index 437ec74..2907410 100644 (file)
--- a/http.php
+++ b/http.php
@@ -1,35 +1,19 @@
 <?php
 
-#  Copyright (C) 2005 Jason Woofenden
-#
-#  This file is part of wfpl.
-#
-#  wfpl is free software; you can redistribute it and/or modify it under the
-#  terms of the GNU Lesser General Public License as published by the Free
-#  Software Foundation; either version 2.1 of the License, or (at your option)
-#  any later version.
-#
-#  wfpl is distributed in the hope that it will be useful, but WITHOUT ANY
-#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-#  FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
-#  more details.
-#
-#  You should have received a copy of the GNU Lesser General Public License
-#  along with wfpl; if not, write to the Free Software Foundation, Inc., 51
-#  Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# This program is in the public domain within the United States. Additionally,
+# we waive copyright and related rights in the work worldwide through the CC0
+# 1.0 Universal public domain dedication, which can be found at
+# http://creativecommons.org/publicdomain/zero/1.0/
 
 
-# return our best guess at the url used to access this page
-function this_url() {
-       list($protocol, $version) = explode('/', $_SERVER['SERVER_PROTOCOL']);
-       $url = strtolower($protocol);
-
-       if($url == 'http') {
-               $expected_port = 80;
-       } elseif ($url == 'https') {
+# return our best guess at the url used to access this page, without the path or query string
+function this_url_sans_path() {
+       if (isset($_SERVER['HTTPS']) && (strtolower($_SERVER['HTTPS']) == 'on' || strtolower($_SERVER['HTTPS']) == 'yes')) {
+               $url = 'https';
                $expected_port = 443;
        } else {
-               $expected_port = -1;
+               $url = 'http';
+               $expected_port = 80;
        }
 
        $url .= '://';
@@ -42,16 +26,68 @@ function this_url() {
                }
        }
 
+       return $url;
+}
+
+# just the hostname, no port number
+function this_host() {
+       if($_SERVER['HTTP_HOST']) {
+               $host = $_SERVER['HTTP_HOST'];
+               $p = strpos($host, ':');
+               if($p) {
+                       $host = substr($host, 0, $p);
+               }
+               return $host;
+       } else {
+               return $_SERVER['SERVER_NAME'];
+       }
+}
+
+
+
+# return our best guess at the url used to access this page
+function this_url() {
+       $url = this_url_sans_path();
+
        $url .= $_SERVER['REQUEST_URI'];
 
        return $url;
 }
 
+# sends an HTTP redirect
+#
+# $url can be:
+#   1) a full URL
+#   2) an absolute path
+#   3) a filename (you can pass a directory/file.html and such, but "../" prefix is not supported yet)
 function redirect($url, $status = '302 Moved Temporarily', $message = '') {
-       header("HTTP/1.1 $status");
+       if(!strpos($url, ':')) {
+               while(substr($url, 0, 2) == './') {
+                       $url = substr($url, 2);
+               }
+               if(substr($url, 0, 1) == '/') {
+                       $url = this_url_sans_path() . $url;
+               } else {
+                       $url = preg_replace('|/[^/]*$|', "/$url", this_url());
+               }
+       }
+                       
+       if(function_exists('session_save_messages')) {
+               if(function_exists('atexit_now')) {
+                       atexit_now();
+               }
+               session_save_messages();
+       }
+
+       header("HTTP/1.0 $status");
        header("Location: $url");
        echo($message);
        exit();
 }
 
-?>
+# output http headers to allow caching of this page forever
+function http_cache_forever($cache_control = 'public') {
+       header('Last-Modified: '.gmdate('D, d M Y H:i:s', 5025) . ' GMT'); # long time ago
+       header("Cache-Control: $cache_control");
+       header('Expires: ' . gmdate('D, d M Y H:i:s',time()+31536000) . ' GMT'); # rfc 2616 says not to go more than a year in the future
+}